Skip to contents

Specifies a cumulative (proportional-odds) model for an ordinal outcome in fit_maihda / maihda, with a choice of link: maihda_cumulative("logit") (the default, equivalent to family = "ordinal") or maihda_cumulative("probit"). It plays the role a stats family object plays for the other families – there is no cumulative family constructor in stats, and using brms::cumulative() would require brms for a frequentist fit.

Usage

maihda_cumulative(link = c("logit", "probit"))

Arguments

The cumulative link: "logit" (default) or "probit". These are the links for which the latent-scale VPC is defined (level-1 variance \(\pi^2/3\) and 1 respectively).

Value

A family marker list with elements family = "cumulative" and link.

See also

Examples

maihda_cumulative()
#> $family
#> [1] "cumulative"
#> 
#> $link
#> [1] "logit"
#> 
maihda_cumulative("probit")
#> $family
#> [1] "cumulative"
#> 
#> $link
#> [1] "probit"
#>