Decomposes the total deviation from the overall mean into the additive (fixed) component
and the intersectional (random) component for each stratum.
Usage
plot_effect_decomposition(
object,
summary_obj,
top_n_labels = 10,
highlight = NULL
)
Arguments
- object
A maihda_model object
- summary_obj
A maihda_summary object
- top_n_labels
Number of most extreme strata to label
- highlight
Optional character vector of stratum ids to highlight. When
supplied, labels are restricted to these strata rather than the most extreme
overall deviations.