run_maihda_app: Run MAIHDA Shiny Application

View source: R/run_app.R

run_maihda_appR Documentation

Run MAIHDA Shiny Application

Description

Launches a Shiny graphical user interface that exposes core functions of the MAIHDA package, allowing for visual data exploration, model fitting, and performance visualization.

Usage

run_maihda_app()

Value

No return value, called to launch the shiny app.

Examples

## Not run: 
run_maihda_app()

## End(Not run)

MAIHDA documentation built on April 5, 2026, 5:06 p.m.