| run_maihda_app | R Documentation |
Launches a Shiny graphical user interface that exposes core functions of the MAIHDA package, allowing for visual data exploration, model fitting, and performance visualization.
run_maihda_app()
No return value, called to launch the shiny app.
## Not run:
run_maihda_app()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.